import { useCallback, useEffect } from 'react'
import { FCC } from '../../types'
import { FieldType, FieldTypes, TypeType } from '../../types/schema'
import { useObjectState } from '../../hooks/useObjectState';
import { useInput } from '../../hooks/useInput';
import { FieldEditor } from './field-editor';

interface IProps {
  name: string;
  saveType: (arg0: string, arg1: TypeType) => void;
  type?: TypeType
}

const constantProperties = ['metadata'];

export const TypeEditor: FCC<IProps> = ({ saveType, name, type: passedType }) => {
  const { update: updateType, reset: resetType, state: type, setState: setType } = useObjectState<TypeType>({});

  const { value: propertyName, bind: bindPropertyName, reset: resetPropertyName } = useInput('', { disallowSpaces: true });

  const save = () => {
    saveType(name, type);
    resetType();
  }

  const addField = useCallback(() => {
    updateType({
      [propertyName]: {
        type: FieldTypes.number,
        value: '',
        isConstant: false,
        limit: 1,
        minimum: 1,
      }
    });
    resetPropertyName();
  }, [propertyName, updateType, resetPropertyName]);

  const updateField = useCallback((k: keyof typeof type) => (field: FieldType) => {
    updateType({ [k]: field })
  }, [updateType]);

  useEffect(() => {
    passedType && setType(passedType);
  }, [passedType, setType]);

  const deleteField = useCallback((name: string) => {
    setType(t => {
      const fields = {...t};
      delete fields[name];
      return fields;
    })
  }, [setType])

  return (
    <div>
      <p className="subheader">{passedType ? 'Editing' : 'Creating'} type "{name}"</p>
      <input type="text" {...bindPropertyName} />
      <button disabled={!propertyName} onClick={addField}>Add Field</button>
      <ul className="rounded-lg overflow-hidden">
        {Object.entries(type).reverse().filter(([k]) => !constantProperties.includes(k)).map(([key, value]) => (
          <FieldEditor field={value} update={updateField(key)} fieldName={key} deleteField={deleteField} />
        ))}
      </ul>
      <div>
        <button onClick={save} disabled={!Object.keys(type).length}>Save Type</button>
      </div>
    </div>
  )
}