import { GameSystem } from '../types/gameSystem';
import { Schema } from '../types/schema';

const emptySchema = { name: '', types: {}, templates: {}, id: crypto.randomUUID() };

export const GameSystemsService = {
  // todo - connect to service to save schema for game
  saveSchema: async (schema: Schema) => {
    localStorage.setItem('schema ' + schema.id, JSON.stringify(schema));

    return { status: 200 }
  },
  // todo - connect to service to fetch schema for game
  getSchema: async (id: string): Promise<{ status: 200 | 404, json: () => Promise<Schema> }> => {
    const schema = localStorage.getItem('schema ' + id);

    if (schema)
      return {
        status: 200,
        json: async () => JSON.parse(schema)
      }

    return {
      status: 404,
      json: async () => (emptySchema)
    }
  },
  getSchemaList: async () => {
    return {
      status: 200, json: async () => [{
        name: 'Test Schema',
        id: '286f4c18-d280-444b-8d7e-9a3dd09f64ef'
      }]
    }
  },
  saveGameSystem: async (gs: GameSystem) => {
    localStorage.setItem('game-system ' + gs.id, JSON.stringify(gs));
    return { status: 200 }
  },
  getGameSystem: async (id: string): Promise<{ status: 200 | 404, json: () => Promise<GameSystem> }> => {
    const gs = localStorage.getItem('game-system ' + id);
    if (!gs) return {status: 404, json:async () => ({
      accolades: [],
      name: '',
      id: crypto.randomUUID(),
      schema: emptySchema,
      schemaId: ''
    })}
    return { status: 200, json:async () => (JSON.parse(gs))}
  }
}